![logo](./readme_img/pyrheadb_logo.png)
Repository for the Python package intended to facilitate access to Rhea data from Python.

Installation and usage
======================
Check [Wiki](https://github.com/sib-swiss/pyrheadb/wiki) for info about installation and usage.


Folder description
==================

## examples
[Jupyter notebooks](examples) containing Rhea analysis using the pyrheadb examples.

## src
Python source code for pyrheadb

## tests
Unit tests for each class of pyrheadb
